@@ -25,6 +25,8 @@
 #include <ctype.h>
 #include <string.h>
 
+int xi_opcode;
+
 typedef int (*prog)(Display* display, int argc, char *argv[],
 		    char *prog_name, char *prog_desc);
 
@@ -83,11 +85,11 @@ static entry drivers[] =
     },
 #if HAVE_XI2
     { "create-master",
-      "<id> [sendCore (dflt:1)] [enable (dflt:1)]",
+      "<id> [<sendCore (dflt:1)>] [<enable (dflt:1)>]",
       create_master
     },
     { "remove-master",
-      "<id> [returnMode (dflt:Floating)] [returnPointer] [returnKeyboard]",
+      "<id> [Floating|AttachToMaster (dflt:Floating)] [<returnPointer>] [<returnKeyboard>]",
       remove_master
     },
     { "reattach",
@@ -257,6 +259,7 @@ main(int argc, char * argv[])
     Display	*display;
     entry	*driver = drivers;
     char        *func;
+    int event, error;
 
     if (argc < 2) {
 	usage();
@@ -270,6 +273,11 @@ main(int argc, char * argv[])
 	return EXIT_FAILURE;
     }
 
+    if (!XQueryExtension(display, "XInputExtension", &xi_opcode, &event, &error)) {
+        printf("X Input extension not available.\n");
+        return EXIT_FAILURE;
+    }
+
     func = argv[1];
     while((*func) == '-') func++;
 
